/* acconfig.h
   This file is in the public domain.

   Descriptive text for the C preprocessor macros that
   the distributed Autoconf macros can define.
   No software package will use all of them; autoheader copies the ones
   your configure.in uses into your configuration header file templates.

   The entries are in sort -df order: alphabetical, case insensitive,
   ignoring punctuation (such as underscores).  Although this order
   can split up related entries, it makes it easier to check whether
   a given entry is in the file.

   Leave the following blank line there!!  Autoheader needs it.  */


#undef HAVE_FRIBIDI
#undef HAVE_UNISTD_H
#undef HAVE_FREETYPE_2_0_3
#undef HAVE_USP10_H

#undef MINI_XFTCONFIG_DIR
#undef HAVE_XFT2
